# Geneva

## A multimodal data platform

`Geneva` is an all-in-one data platform to manage petabytes of multimodal data.

It builds on top of the open-source project [LanceDB](https://github.com/lancedb/lancedb) and
offers the simplest and most efficient developer experience.

<div class="grid cards" markdown>
- :material-code-braces:  __Feature Engineering__

    ---
    Run large scale feature engineering with great control
    and ease.

    [:octicons-arrow-right-24: Feature Engineering](./features.md)

- :simple-googlebigquery: __Exploratory Data Analysis__

    ---
    Fast SQL Data Exploration via Geneva distributed SQL engine

    [:octicons-arrow-right-24: SQL Exploration](./sql.md)

- :simple-pytorch: __PyTorch Training__

    ---
    Use Lance in Distributed PyTorch Training with caching

    [:octicons-arrow-right-24: PyTorch Training](./torch.md)

</div>
